.. _isomorphism:

***********
Isomorphism
***********

.. toctree::
   :maxdepth: 2

.. currentmodule:: networkx

.. autosummary::
   :toctree: generated/

   is_isomorphic
   could_be_isomorphic
   fast_could_be_isomorphic
   faster_could_be_isomorphic

Advanced Interface to VF2 Algorithm
-----------------------------------
.. toctree::
   :maxdepth: 2

   algorithms.isomorphism.vf2


